# template name attributes
%define templatename rhel
%define templatever 9
%define templatearch x86_64

# Human-readable attributes
%define fullname Centos %templatever
%define fulltemplatearch (for AMD64/Intel EM64T)

# template dirs
%define templatedir /vz/template/%templatename/%templatever/%templatearch/config
%define ostemplatedir %templatedir/os/default

# vzpkgenv related
%define pkgman 417x64
%define package_manager rpm%pkgman
%define package_manager_pkg vzpkgenv%pkgman >= 7.0.0

# Files lists
%define files_lst() \
find %1 -type d -printf '%%%dir %%%attr(%m,root,root) %p\\n' | sed "s,%buildroot,,g" >> %2\
find %1 -type f -printf '%%%config %%%attr(%m,root,root) %p\\n' | sed "s,%buildroot,,g" >> %2\
%nil

# Sources list
%define sources_lst() \
%((cd %_sourcedir;\
s=1;\
for tmpl in %1; do\
sources=$tmpl"_*";\
for file in $sources; do\
echo Source$s: $file;\
s=$((s+1))\
done;\
done))\
%nil

# Templates list - packages file should be always present in any template!
%define templates_list() %((cd %_sourcedir; for f in *_packages; do echo -n "${f%_*} "; done))

Summary: %fullname %fulltemplatearch Template set
Name: %templatename-%templatever-%templatearch-ez
Group: Virtuozzo/Templates
License: GPL
Version: 7.0.0
Release: 8%{?dist}
BuildRoot: %_tmppath/%name-root
BuildArch: noarch
Requires: %package_manager_pkg
Requires: rhel-9-netrepo
Source1000: network-scripts-10.11.5-1.el9.x86_64.rpm
Source1001: network-scripts-ppp-2.4.9-5.el9.x86_64.rpm
Source1002: network-scripts-teamd-1.31-16.el9_1.x86_64.rpm
Source1003: repodata.tar.gz
# Requires: pki-tools

# template source files
%sources_lst %templates_list

%description
%fullname %fulltemplatearch packaged as a Virtuozzo Template set.

%install
installfile() {
	local sourcename=%_sourcedir/${1}_$4
	local mode=$2
	local dir=$3
	local name=$4

	[ ! -f $sourcename ] && return

	install -m $mode $sourcename $dir/$name
}

rm -f files.lst
for tmpl in %templates_list; do
	[ $tmpl = "os" ] && dir=%buildroot/%ostemplatedir || \
		dir=%buildroot/%templatedir/app/$tmpl/default

	mkdir -p $dir

	if [ $tmpl = "os" ]; then
		# Os template only files

		# Text
		echo "%fullname %fulltemplatearch Virtuozzo Template" > $dir/description
		echo "%fullname %fulltemplatearch Virtuozzo Template" > $dir/summary

		# Package manager
		echo "%package_manager" > $dir/package_manager

		# Disable upgrade
		touch $dir/upgradable_versions

		# Pkgman environment
		installfile $tmpl 0644 $dir environment

		# vzctl-related
		installfile $tmpl 0644 $dir distribution

		# Kernel virtualization
		installfile $tmpl 0644 $dir osrelease

		# Os template cache scripts
		installfile $tmpl 0755 $dir pre-cache
		installfile $tmpl 0755 $dir post-cache
		installfile $tmpl 0755 $dir ct2vm
		installfile $tmpl 0755 $dir mid-pre-install
		installfile $tmpl 0755 $dir mid-post-install
		installfile $tmpl 0755 $dir pre-upgrade
		installfile $tmpl 0755 $dir post-upgrade
		# needed only for vzdummy rpm
		echo 'https://repo.virtuozzo.com/ctpreset/rpm/' >> $dir/repositories
		echo 'file:/vz/template/rhel/rhel-9-netrepo/' >> $dir/repositories
		echo 'https://cdn.redhat.com/content/dist/rhel9/9/x86_64/appstream/os' >> $dir/repositories
		echo 'https://cdn.redhat.com/content/dist/rhel9/9/x86_64/baseos/os' >> $dir/repositories
	else
		# App templates only files

		# Text
		echo "$tmpl for %fullname %fulltemplatearch Virtuozzo Template" > $dir/description
		echo "$tmpl for %fullname %fulltemplatearch Virtuozzo Template" > $dir/summary
	fi

	# Common things

	# Installation sources
	installfile $tmpl 0644 $dir mirrorlist
	installfile $tmpl 0644 $dir repositories

	# Packages
	installfile $tmpl 0644 $dir packages

	# Scripts
	installfile $tmpl 0755 $dir pre-install
	installfile $tmpl 0755 $dir pre-install-hn
	installfile $tmpl 0755 $dir post-install
	installfile $tmpl 0755 $dir post-install-hn

	# Versioning
	echo "%release" > $dir/release
	echo "%version" > $dir/version
	%files_lst $dir files.lst
done

mkdir -p %{buildroot}/vz/template/rhel/rhel-9-netrepo/
install -m 644 %{SOURCE1000} %{buildroot}/vz/template/rhel/rhel-9-netrepo/
install -m 644 %{SOURCE1001} %{buildroot}/vz/template/rhel/rhel-9-netrepo/
install -m 644 %{SOURCE1002} %{buildroot}/vz/template/rhel/rhel-9-netrepo/
cp %{SOURCE1003} %{buildroot}/vz/template/rhel/rhel-9-netrepo/
tar -xvzf %{buildroot}/vz/template/rhel/rhel-9-netrepo/repodata.tar.gz -C %{buildroot}/vz/template/rhel/rhel-9-netrepo/
rm -f %{buildroot}/vz/template/rhel/rhel-9-netrepo/repodata.tar.gz

%files -f files.lst

%package -n	rhel-9-netrepo
Summary:	Additional Network scripts repository for RHEL9
BuildArch:  noarch
Group:		Virtuozzo/Templates
License:	GPL

%description -n rhel-9-netrepo
Additional Network scripts repository for RHEL9

%files -n rhel-9-netrepo
/vz/template/rhel/rhel-9-netrepo/*
/vz/template/rhel/rhel-9-netrepo/repodata/*

%changelog
* Tue Oct 31 2023 Artem Vasiliev <artem.vasiliev@virtuozzo.com> 7.0.0-7
- RHEL ford from almalinux EZ template, PSBM-149627

* Tue Dec 14 2021 Denis Silakov <dsilakov@virtuozzo.com> 7.0.0-14
- More pre-upgrade fixes, PSBM-136635

* Mon Aug 30 2021 Denis Silakov <dsilakov@virtuozzo.com> 7.0.0-10
- Add upgrade scripts, PSBM-133584
- Adjust mysql packages, PSBM-133315

* Thu Jul  13 2021 Alexander Stefanov <astefanov@virtuozzo.com> 7.0.0-8
- add dovecot #PSBM-99957

* Thu Jul  8 2021 Denis Silakov <dsilakov@virtuozzo.com> 7.0.0-7
- Add mariadb-connector to mysql template, PSBM-131151

* Mon Jan 27 2020 Alex Stefanov <astefanov@virtuozzo.com> 7.0.0-6
- include annobin in dev template too, see #PSBM-100858

* Thu Nov 21 2019 Konstantin Volckov <wolf@sw.ru> 7.0.0-5
- Add php-fpm package to php app template, see #PSBM-99691

* Thu Nov 21 2019 Konstantin Volckov <wolf@sw.ru> 7.0.0-4
- Do not use virtual package names in apptemplates, see #PSBM-99623

* Tue Nov 19 2019 Konstantin Volckov <wolf@sw.ru> 7.0.0-3
- Export DNF_RELEASEVER and DNF_PLATFORM_ID, see #PSBM-99503
- Switch to nftables firewalld backend, see #PSBM-99511

* Thu Nov 14 2019 Konstantin Volckov <wolf@sw.ru> 7.0.0-2
- Turn firewalld IndividualCalls back to default setting (no), see #PSBM-99110

* Mon Sep 30 2019 Konstantin Volckov <wolf@sw.ru> 7.0.0-1
- Initial release, see #PSBM-93343
